PixelStorageMode

Enum PixelStorageMode 

pub enum PixelStorageMode {
Show 13 variants UnpackFlipYWebgl = 37_440, UnpackPremultiplyAlphaWebgl = 37_441, UnpackColorspaceConversionWebgl = 37_443, PackAlignment = 3_333, UnpackAlignment = 3_317, PackRowLength = 3_330, PackSkipPixels = 3_332, PackSkipRows = 3_331, UnpackRowLength = 3_314, UnpackImageHeight = 32_878, UnpackSkipPixels = 3_316, UnpackSkipRows = 3_315, UnpackSkipImages = 32_877,
}
Constants passed to WebGLRenderingContext.pixelStorei()

Variants



UnpackFlipYWebgl = 37_440



UnpackPremultiplyAlphaWebgl = 37_441



UnpackColorspaceConversionWebgl = 37_443



PackAlignment = 3_333

Packing of pixel data into memory. Can be 1, 2, 4, 8 defaults to 4



UnpackAlignment = 3_317

Unpacking of pixel data from memory Can be 1, 2, 4, 8 defaults to 4



PackRowLength = 3_330

Number of pixels in a row.



PackSkipPixels = 3_332

Number of pixel locations skipped before the first pixel is written into memory.



PackSkipRows = 3_331

Number of rows of pixel locations skipped before the first pixel is written into memory



UnpackRowLength = 3_314

Number of pixels in a row.



UnpackImageHeight = 32_878

Image height used for reading pixel data from memory



UnpackSkipPixels = 3_316

Number of pixel images skipped before the first pixel is read from memory



UnpackSkipRows = 3_315

Number of rows of pixel locations skipped before the first pixel is read from memory



UnpackSkipImages = 32_877

Number of pixel images skipped before the first pixel is read from memory